searchNodes=[{"doc":"This module provides the base functionality to work with the Scrypt KDF.","ref":"Scrypt.html","title":"Scrypt","type":"module"},{"doc":"Creates an Scrypt hash from the given parameters, allowing a custom salt and key length. Examples iex&gt; Scrypt.hash(&quot;hunter2&quot;, &quot;oftheearth&quot;, 14, 8, 1, 64) &lt;&lt;66, 229, 151, 70, 35, 13, 211, 30, 1, 153, 91, 172, 42, 194, 249, 50, 229, 34, 92, 157, 115, 218, 91, 163, 223, 167, 219, 42, 90, 20, 93, 163, 101, 225, 98, 198, 152, 96, 97, 86, 50, 220, 91, 22, 5, 160, 199, 150, 150, 253, ...&gt;&gt;","ref":"Scrypt.html#hash/6","title":"Scrypt.hash/6","type":"function"},{"doc":"Generates an Scrypt header from the given parameters, using 32 bytes hash and a 64 bytes key length. If a salt is not given, one is generated with :crypto.strong_rand_bytes(n :: non_neg_integer()) Examples iex&gt; Scrypt.kdf(&quot;hunter2&quot;, 14, 8, 1) &lt;&lt;115, 99, 114, 121, 112, 116, 0, 14, 0, 0, 0, 8, 0, 0, 0, 1, 166, 59, 141, 39, 16, 29, 92, 191, 50, 7, 102, 174, 27, 240, 229, 27, 121, 234, 97, 111, 98, 182, 29, 158, 117, 43, 9, 141, 172, 189, 106, 88, 213, 152, ...&gt;&gt; iex&gt; Scrypt.kdf(&quot;hunter2&quot;, :crypto.strong_rand_bytes(32), 14, 8, 1) &lt;&lt;115, 99, 114, 121, 112, 116, 0, 14, 0, 0, 0, 8, 0, 0, 0, 1, 120, 127, 46, 232, 104, 21, 51, 3, 154, 50, 72, 127, 172, 43, 131, 37, 182, 149, 168, 88, 27, 146, 85, 169, 52, 134, 20, 143, 37, 97, 197, 66, 148, 182, ...&gt;&gt;","ref":"Scrypt.html#kdf/4","title":"Scrypt.kdf/4","type":"function"},{"doc":"","ref":"Scrypt.html#kdf/5","title":"Scrypt.kdf/5","type":"function"},{"doc":"Copied from: https://github.com/elixir-plug/plug/blob/v1.5.0-rc.2/lib/plug/crypto.ex#L102 Compares the two binaries in constant-time to avoid timing attacks. See: http://codahale.com/a-lesson-in-timing-attacks/","ref":"Scrypt.html#secure_compare/2","title":"Scrypt.secure_compare/2","type":"function"},{"doc":"Verifies an Scrypt hash. Examples iex(1)&gt; hash = Scrypt.hash(&quot;hunter2&quot;, &quot;oftheearth&quot;, 14, 8, 1, 64) &lt;&lt;66, 229, 151, 70, 35, 13, 211, 30, 1, 153, 91, 172, 42, 194, 249, 50, 229, 34, 92, 157, 115, 218, 91, 163, 223, 167, 219, 42, 90, 20, 93, 163, 101, 225, 98, 198, 152, 96, 97, 86, 50, 220, 91, 22, 5, 160, 199, 150, 150, 253, ...&gt;&gt; iex(2)&gt; Scrypt.verify?(hash, &quot;hunter2&quot;, &quot;oftheearth&quot;, 14, 8, 1) true","ref":"Scrypt.html#verify?/6","title":"Scrypt.verify?/6","type":"function"},{"doc":"Decodes and verifies an Scrypt header using a supplied password, following the documented specs. +----------+--------+----------------------------------------------------------+ | offset | length | assignment | +----------+--------+----------------------------------------------------------+ | 0 | 6 | &quot;scrypt&quot; | | 6 | 1 | scrypt data file version number (== 0) | | 7 | 1 | log2(N) (must be between 1 and 63 inclusive) | | 8 | 4 | r (big-endian integer; must satisfy r * p &lt; 2^30) | | 12 | 4 | p (big-endian integer; must satisfy r * p &lt; 2^30) | | 16 | 32 | salt | | 48 | 16 | first 16 bytes of SHA256(bytes 0 .. 47) | | 64 | 32 | HMAC-SHA256(bytes 0 .. 63) | | 96 | X | data xor AES256-CTR key stream generated with nonce == 0 | | 96+X | 32 | HMAC-SHA256(bytes 0 .. 96 + (X - 1)) | +----------+--------+----------------------------------------------------------+ Examples iex(1)&gt; header = Scrypt.kdf(&quot;hunter2&quot;, 14, 8, 1) &lt;&lt;115, 99, 114, 121, 112, 116, 0, 14, 0, 0, 0, 8, 0, 0, 0, 1, 66, 223, 14, 146, 240, 251, 4, 70, 177, 59, 232, 159, 183, 134, 188, 127, 72, 170, 70, 224, 134, 201, 74, 15, 188, 227, 34, 222, 250, 192, 153, 226, 42, 189, ...&gt;&gt; iex(2)&gt; Scrypt.verify_kdf?(header, &quot;hunter2&quot;) true","ref":"Scrypt.html#verify_kdf?/2","title":"Scrypt.verify_kdf?/2","type":"function"},{"doc":"","ref":"Scrypt.NIF.html","title":"Scrypt.NIF","type":"module"},{"doc":"","ref":"Scrypt.NIF.html#hash_nif/6","title":"Scrypt.NIF.hash_nif/6","type":"function"},{"doc":"","ref":"Scrypt.NIF.html#init/0","title":"Scrypt.NIF.init/0","type":"function"},{"doc":"ScryptElixir Elixir wrapper for the Scrypt key derivation function. https://www.tarsnap.com/scrypt.html","ref":"readme.html","title":"ScryptElixir","type":"extras"},{"doc":"This library provides raw scrypt hashing functionality as well as an implementation of the original suggested KDF. hash/6 is a lower level function that allows for a custom salt length and derived key length. The result is the raw binary scrypt hash. This function allows for custom salts and derived key lengths. kdf/4 is a function that creates an Scrypt header that utilizes HMAC to ensure hash integrity. This implementation enforces a 32 byte salt length and 64 byte derived key length. kdf/5 creates an Scrypt header, but allows for a custom 32 byte salt. verify?/6 validates an Scrypt hash using the supplied parameters, returning a boolean. verify_kdf?/2 validates an Scrypt header using the supplied password. Both functions rely on a core set of parameters: password - the core binary being hashed salt - a pseudo-randomly generated string of bytes used for hashing logN - exponent for CPU/memory cost (2^logN) r - blocksize","ref":"readme.html#usage","title":"ScryptElixir - Usage","type":"extras"},{"doc":"The package can be installed by adding scrypt_elixir to your list of dependencies in mix.exs: def deps do [ {:scrypt_elixir, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be found at https://hexdocs.pm/scrypt_elixir.","ref":"readme.html#installation","title":"ScryptElixir - Installation","type":"extras"}]